# Generated by Django 3.2 on 2023-01-13 15:25

from django.db import migrations, models
import django.db.models.deletion
import filer.fields.file


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('filer', '0015_alter_file_owner_alter_file_polymorphic_ctype_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='PDFEmbedModel',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='pdfembed_pdfembedmodel', serialize=False, to='cms.cmsplugin')),
                ('height', models.CharField(default='500px', max_length=10)),
                ('width', models.CharField(default='100%', max_length=10)),
                ('pdf', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='filer.file', verbose_name='PDF')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
